package com.ycwl.basic.image.watermark.operator;

import com.ycwl.basic.image.watermark.entity.WatermarkInfo;
import com.ycwl.basic.image.watermark.exception.ImageWatermarkException;
import lombok.extern.slf4j.Slf4j;

import javax.imageio.ImageIO;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;

@Slf4j
public class DefaultImageWatermarkOperator implements IOperator {
    @Override
    public File process(WatermarkInfo info) throws ImageWatermarkException {
        BufferedImage baseImage;
        BufferedImage watermarkImage;
        InputStream logoInputStream = getClass().getResourceAsStream("/watermark.png");
        if (logoInputStream == null) {
            throw new ImageWatermarkException("无法找到 watermark.png 资源文件");
        }
        try {
            baseImage = ImageIO.read(info.getOriginalFile());
            watermarkImage = ImageIO.read(logoInputStream);
        } catch (IOException e) {
            throw new ImageWatermarkException("图片打开失败");
        }
        // 新图像画布
        BufferedImage newImage = new BufferedImage(baseImage.getWidth(), baseImage.getHeight(), BufferedImage.TYPE_INT_RGB);
        Graphics2D g2d = newImage.createGraphics();
        g2d.drawImage(baseImage, 0, 0, null);
        g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        g2d.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_ATOP, 0.5f));
        g2d.drawImage(watermarkImage, 0, 0,  baseImage.getWidth(), baseImage.getHeight(), null);
        try {
            ImageIO.write(newImage, "jpg", info.getWatermarkedFile());
        } catch (IOException e) {
            throw new ImageWatermarkException("图片保存失败");
        } finally {
            g2d.dispose();
        }
        return info.getWatermarkedFile();
    }
}
